@@ -3,12 +3,12 @@ package clusterrole
 import (
 	"context"
 
-	clusterv1 "github.com/open-cluster-management/api/cluster/v1"
-	"github.com/stolostron/multicloud-operators-foundation/pkg/utils"
+	"github.com/open-cluster-management/multicloud-operators-foundation/pkg/utils"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/client-go/kubernetes"
 	"k8s.io/klog"
+	clusterv1 "open-cluster-management.io/api/cluster/v1"
 	ctrl "sigs.k8s.io/controller-runtime"
 	"sigs.k8s.io/controller-runtime/pkg/client"
 	"sigs.k8s.io/controller-runtime/pkg/controller"
@@ -137,7 +137,7 @@ func (r *Reconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Resu
 		managedClusterKey: cluster.GetName(),
 	}
 	var modified = false
-	utils.MergeMap(&modified, clusterNamespace.GetLabels(), ClusterNameLabel)
+	utils.MergeMap(&modified, &clusterNamespace.Labels, ClusterNameLabel)
 
 	if modified {
 		_, err = r.kubeClient.CoreV1().Namespaces().Update(context.TODO(), clusterNamespace, metav1.UpdateOptions{})
