@@ -10,8 +10,8 @@ import (
 	"sigs.k8s.io/controller-runtime/pkg/client"
 	"sigs.k8s.io/controller-runtime/pkg/manager"
 
-	actionv1beta1 "github.com/stolostron/multicloud-operators-foundation/pkg/apis/action/v1beta1"
-	"github.com/stolostron/multicloud-operators-foundation/pkg/utils/rest"
+	actionv1beta1 "github.com/open-cluster-management/multicloud-operators-foundation/pkg/apis/action/v1beta1"
+	"github.com/open-cluster-management/multicloud-operators-foundation/pkg/utils/rest"
 )
 
 var c client.Client
@@ -40,10 +40,10 @@ func TestControllerReconcile(t *testing.T) {
 	SetupTestReconcile(ar)
 	ar.SetupWithManager(mgr)
 
-	stopMgr, mgrStopped := StartTestManager(mgr, g)
+	cancel, mgrStopped := StartTestManager(mgr, g)
 
 	defer func() {
-		close(stopMgr)
+		cancel()
 		mgrStopped.Wait()
 	}()
 
