@@ -4,12 +4,8 @@ import (
 	"context"
 	"fmt"
 
-	clientset "github.com/open-cluster-management/api/client/cluster/clientset/versioned"
-	clusterv1alpha1lister "github.com/open-cluster-management/api/client/cluster/listers/cluster/v1alpha1"
-	clusterv1 "github.com/open-cluster-management/api/cluster/v1"
-	clusterv1alpha1 "github.com/open-cluster-management/api/cluster/v1alpha1"
-	"github.com/stolostron/multicloud-operators-foundation/pkg/cache"
-	"github.com/stolostron/multicloud-operators-foundation/pkg/proxyserver/helpers"
+	"github.com/open-cluster-management/multicloud-operators-foundation/pkg/cache"
+	"github.com/open-cluster-management/multicloud-operators-foundation/pkg/proxyserver/helpers"
 	"k8s.io/apimachinery/pkg/api/errors"
 	metainternalversion "k8s.io/apimachinery/pkg/apis/meta/internalversion"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -19,6 +15,9 @@ import (
 	"k8s.io/apiserver/pkg/endpoints/request"
 	"k8s.io/apiserver/pkg/registry/rest"
 	rbaclisters "k8s.io/client-go/listers/rbac/v1"
+	clientset "open-cluster-management.io/api/client/cluster/clientset/versioned"
+	clusterv1beta1lister "open-cluster-management.io/api/client/cluster/listers/cluster/v1beta1"
+	clusterv1beta1 "open-cluster-management.io/api/cluster/v1beta1"
 )
 
 type REST struct {
@@ -27,7 +26,7 @@ type REST struct {
 	lister cache.ClusterSetLister
 
 	clusterSetCache   *cache.ClusterSetCache
-	clusterSetLister  clusterv1alpha1lister.ManagedClusterSetLister
+	clusterSetLister  clusterv1beta1lister.ManagedClusterSetLister
 	clusterRoleLister rbaclisters.ClusterRoleLister
 	tableConverter    rest.TableConvertor
 }
@@ -37,7 +36,7 @@ func NewREST(
 	client clientset.Interface,
 	lister cache.ClusterSetLister,
 	clusterSetCache *cache.ClusterSetCache,
-	clusterSetLister clusterv1alpha1lister.ManagedClusterSetLister,
+	clusterSetLister clusterv1beta1lister.ManagedClusterSetLister,
 	clusterRoleLister rbaclisters.ClusterRoleLister,
 ) *REST {
 	return &REST{
@@ -47,13 +46,13 @@ func NewREST(
 		clusterSetCache:   clusterSetCache,
 		clusterSetLister:  clusterSetLister,
 		clusterRoleLister: clusterRoleLister,
-		tableConverter:    rest.NewDefaultTableConvertor(clusterv1.Resource("managedclustersets")),
+		tableConverter:    rest.NewDefaultTableConvertor(clusterv1beta1.Resource("managedclustersets")),
 	}
 }
 
 // New returns a new managedClusterSet
 func (s *REST) New() runtime.Object {
-	return &clusterv1alpha1.ManagedClusterSet{}
+	return &clusterv1beta1.ManagedClusterSet{}
 }
 
 func (s *REST) NamespaceScoped() bool {
@@ -62,7 +61,7 @@ func (s *REST) NamespaceScoped() bool {
 
 // NewList returns a new managedClusterSet list
 func (*REST) NewList() runtime.Object {
-	return &clusterv1alpha1.ManagedClusterSetList{}
+	return &clusterv1beta1.ManagedClusterSetList{}
 }
 
 var _ = rest.Lister(&REST{})
@@ -71,7 +70,7 @@ var _ = rest.Lister(&REST{})
 func (s *REST) List(ctx context.Context, options *metainternalversion.ListOptions) (runtime.Object, error) {
 	user, ok := request.UserFrom(ctx)
 	if !ok {
-		return nil, errors.NewForbidden(clusterv1.Resource("managedclustersets"), "", fmt.Errorf("unable to list managedClusterset without a user on the context"))
+		return nil, errors.NewForbidden(clusterv1beta1.Resource("managedclustersets"), "", fmt.Errorf("unable to list managedClusterset without a user on the context"))
 	}
 
 	labelSelector, _ := helpers.InternalListOptionsToSelectors(options)
@@ -95,7 +94,7 @@ func (s *REST) Watch(ctx context.Context, options *metainternalversion.ListOptio
 	}
 	user, ok := request.UserFrom(ctx)
 	if !ok {
-		return nil, errors.NewForbidden(clusterv1.Resource("managedclustersets"), "", fmt.Errorf("unable to list managedClusterSet without a user on the context"))
+		return nil, errors.NewForbidden(clusterv1beta1.Resource("managedclustersets"), "", fmt.Errorf("unable to list managedClusterSet without a user on the context"))
 	}
 
 	includeAllExistingClusterSets := (options != nil) && options.ResourceVersion == "0"
@@ -112,7 +111,7 @@ var _ = rest.Getter(&REST{})
 func (s *REST) Get(ctx context.Context, name string, options *metav1.GetOptions) (runtime.Object, error) {
 	user, ok := request.UserFrom(ctx)
 	if !ok {
-		return nil, errors.NewForbidden(clusterv1.Resource("managedclustersets"), "", fmt.Errorf("unable to get managedClusterSet without a user on the context"))
+		return nil, errors.NewForbidden(clusterv1beta1.Resource("managedclustersets"), "", fmt.Errorf("unable to get managedClusterSet without a user on the context"))
 	}
 
 	clusterSetList, err := s.lister.List(user, labels.Everything())
@@ -125,5 +124,5 @@ func (s *REST) Get(ctx context.Context, name string, options *metav1.GetOptions)
 		}
 	}
 
-	return nil, errors.NewForbidden(clusterv1.Resource("managedclustersets"), "", fmt.Errorf("the user cannot get the managedClusterSet %v", name))
+	return nil, errors.NewForbidden(clusterv1beta1.Resource("managedclustersets"), "", fmt.Errorf("the user cannot get the managedClusterSet %v", name))
 }
