@@ -8,9 +8,9 @@ import (
 	"github.com/onsi/ginkgo"
 	"github.com/onsi/gomega"
 
-	clusterinfov1beta1 "github.com/stolostron/multicloud-operators-foundation/pkg/apis/internal.open-cluster-management.io/v1beta1"
-	"github.com/stolostron/multicloud-operators-foundation/pkg/proxyserver/apis/proxy/v1beta1"
-	"github.com/stolostron/multicloud-operators-foundation/test/e2e/util"
+	clusterinfov1beta1 "github.com/open-cluster-management/multicloud-operators-foundation/pkg/apis/internal.open-cluster-management.io/v1beta1"
+	"github.com/open-cluster-management/multicloud-operators-foundation/pkg/proxyserver/apis/proxy/v1beta1"
+	"github.com/open-cluster-management/multicloud-operators-foundation/test/e2e/util"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/cli-runtime/pkg/resource"
 	"k8s.io/client-go/rest"
@@ -18,7 +18,7 @@ import (
 )
 
 var _ = ginkgo.Describe("Testing Pod log", func() {
-	podNamespace := "open-cluster-management-agent"
+	podNamespace := "open-cluster-management-agent-addon"
 	var podName string
 	var containerName string
 	var restClient *rest.RESTClient
@@ -71,7 +71,7 @@ var _ = ginkgo.Describe("Testing Pod log", func() {
 	ginkgo.It("should get log from pod successfully", func() {
 		// check the ManagedClusterInfo status
 		gomega.Eventually(func() error {
-			managedClusterInfo, err := util.GetResource(dynamicClient, clusterInfoGVR, defaultManagedCluster, defaultManagedCluster)
+			managedClusterInfo, err := util.GetResource(dynamicClient, util.ClusterInfoGVR, defaultManagedCluster, defaultManagedCluster)
 			if err != nil {
 				return err
 			}
